@@ -1,20 +1,20 @@
 /*
-  Copyright (C) 2003-2010 FreeIPMI Core Team
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software Foundation,
-  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
-*/
+ * Copyright (C) 2003-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
 
 #ifndef _TOOL_CMDLINE_COMMON_H
 #define _TOOL_CMDLINE_COMMON_H
@@ -31,6 +31,8 @@
 
 #include <freeipmi/freeipmi.h>
 
+#include "parse-common.h"
+
 enum argp_common_option_keys
   {
     ARGP_DRIVER_TYPE_KEY = 'D',
@@ -216,8 +218,10 @@ struct common_cmd_args
   int cipher_suite_id;
   int privilege_level;
   char *config_file;
-  unsigned int workaround_flags;
-  unsigned int tool_specific_workaround_flags;
+  unsigned int workaround_flags_outofband;
+  unsigned int workaround_flags_outofband_2_0;
+  unsigned int workaround_flags_inband;
+  unsigned int section_specific_workaround_flags;
   int debug;
 };
 
@@ -239,81 +243,6 @@ struct hostrange_cmd_args
   int always_prefix;
 };
 
-#define IPMI_DEVICE_LAN_STR      "lan"
-#define IPMI_DEVICE_LAN_2_0_STR  "lan_2_0"
-#define IPMI_DEVICE_KCS_STR      "kcs"
-#define IPMI_DEVICE_SSIF_STR     "ssif"
-#define IPMI_DEVICE_OPENIPMI_STR "openipmi"
-#define IPMI_DEVICE_SUNBMC_STR   "sunbmc"
-
-#define IPMI_TOOL_WORKAROUND_FLAGS_DEFAULT                         0x00000000
-#define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO          0x00000001
-#define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION     0x00000002
-#define IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE       0x00000004
-#define IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER      0x00000008
-#define IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES     0x00000010
-#define IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION               0x00000020
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION          0x00000040
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION                 0x00000080
-#define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE          0x00000100
-#define IPMI_TOOL_WORKAROUND_FLAGS_NON_EMPTY_INTEGRITY_CHECK_VALUE 0x00000200
-#define IPMI_TOOL_WORKAROUND_FLAGS_ASSUME_IO_BASE_ADDRESS          0x00000400
-
-#define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO_STR          "idzero"
-#define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION_STR     "forcepermsg"
-#define IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE_STR       "unexpectedauth"
-#define IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER_STR      "endianseq"
-#define IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES_STR     "authcap"
-#define IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION_STR               "intel20"
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION_STR          "supermicro20"
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION_STR                 "sun20"
-#define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE_STR          "opensesspriv"
-#define IPMI_TOOL_WORKAROUND_FLAGS_NON_EMPTY_INTEGRITY_CHECK_VALUE_STR "integritycheckvalue"
-#define IPMI_TOOL_WORKAROUND_FLAGS_ASSUME_IO_BASE_ADDRESS_STR          "assumeio"
-
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE     0x00000001
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PORT             0x00000002
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_SOL_ACTIVATION_STATUS  0x00000004
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_CHECKS                 0x00000008
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_ASSUME_SYSTEM_EVENT         0x00000010
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SLOW_COMMIT                 0x00000020
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_VERY_SLOW_COMMIT            0x00000040
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_STATE_FLAG           0x00000080
-
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE_STR    "solpayloadsize"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PORT_STR            "solport"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_SOL_ACTIVATION_STATUS_STR "solstatus"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_CHECKS_STR                "skipchecks"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_ASSUME_SYSTEM_EVENT_STR        "assumesystemevent"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SLOW_COMMIT_STR                "slowcommit"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_VERY_SLOW_COMMIT_STR           "veryslowcommit"
-#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_STATE_FLAG_STR          "ignorestateflag"
-
-#define IPMI_AUTHENTICATION_TYPE_NONE_STR                               "none"
-#define IPMI_AUTHENTICATION_TYPE_STRAIGHT_PASSWORD_KEY_STR              "straight_password_key"
-#define IPMI_AUTHENTICATION_TYPE_STRAIGHT_PASSWORD_KEY_STR_OLD          "plain"
-#define IPMI_AUTHENTICATION_TYPE_MD2_STR                                "md2"
-#define IPMI_AUTHENTICATION_TYPE_MD5_STR                                "md5"
-
-#define IPMI_PRIVILEGE_LEVEL_USER_STR                                   "user"
-#define IPMI_PRIVILEGE_LEVEL_OPERATOR_STR                               "operator"
-#define IPMI_PRIVILEGE_LEVEL_ADMIN_STR                                  "admin"
-#define IPMI_PRIVILEGE_LEVEL_ADMIN_STR2                                 "administrator"
-
-int parse_inband_driver_type (const char *str);
-
-int parse_outofband_driver_type (const char *str);
-
-int parse_driver_type (const char *str);
-
-int parse_authentication_type (const char *str);
-
-int parse_privilege_level (const char *str);
-
-int parse_workaround_flags (const char *str,
-                            unsigned int *workaround_flags,
-                            unsigned int *tool_specific_workaround_flags);
-
 error_t common_parse_opt (int key,
                           char *arg,
                           struct common_cmd_args *common_cmd_args);
@@ -330,6 +259,8 @@ void init_common_cmd_args_user (struct common_cmd_args *cmd_args);
 void init_common_cmd_args_operator (struct common_cmd_args *cmd_args);
 void init_common_cmd_args_admin (struct common_cmd_args *cmd_args);
 void free_common_cmd_args (struct common_cmd_args *cmd_args);
+void verify_common_cmd_args_inband (struct common_cmd_args *cmd_args);
+void verify_common_cmd_args_outofband (struct common_cmd_args *cmd_args, int check_hostname);
 void verify_common_cmd_args (struct common_cmd_args *cmd_args);
 
 void init_sdr_cmd_args (struct sdr_cmd_args *sdr_cmd_args);
