@@ -130,11 +130,10 @@ dmidecode_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -148,11 +147,10 @@ dmidecode_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -166,11 +164,10 @@ dmidecode_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -184,11 +181,10 @@ dmidecode_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -212,11 +208,10 @@ smbios_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -230,11 +225,10 @@ smbios_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -248,11 +242,10 @@ smbios_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -266,11 +259,10 @@ smbios_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -294,11 +286,10 @@ acpi_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -312,11 +303,10 @@ acpi_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -330,11 +320,10 @@ acpi_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -348,11 +337,10 @@ acpi_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -376,11 +364,10 @@ pci_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -394,11 +381,10 @@ pci_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -412,11 +398,10 @@ pci_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -430,11 +415,10 @@ pci_probe_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -458,11 +442,10 @@ defaults_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -476,11 +459,10 @@ defaults_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 
@@ -498,11 +480,10 @@ defaults_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
 #else /* !0 */
@@ -522,11 +503,10 @@ defaults_display (ipmi_locate_ctx_t ctx)
     }
   else
     {
-#ifndef NDEBUG
-      printf ("FAILED: %s\n", ipmi_locate_ctx_errormsg (ctx));
-#else
-      printf ("FAILED\n");
-#endif
+      if (ipmi_locate_ctx_errnum (ctx) == IPMI_LOCATE_ERR_SYSTEM_ERROR)
+	printf ("FAILED\n");
+      else
+	printf ("ERROR: %s\n", ipmi_locate_ctx_errormsg (ctx));
     }
   printf ("\n");
   return;
