@@ -21,6 +21,9 @@
 
 #include "ipmi-oem.h"
 
+int ipmi_oem_intel_get_smtp_config (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_intel_set_smtp_config (ipmi_oem_state_data_t *state_data);
+
 int ipmi_oem_intel_restore_configuration (ipmi_oem_state_data_t *state_data);
 
 #endif
