@@ -1,20 +1,20 @@
 /*
-  Copyright (C) 2008-2010 FreeIPMI Core Team
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software Foundation,
-  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
-*/
+ * Copyright (C) 2008-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
 
 #if HAVE_CONFIG_H
 #include "config.h"
@@ -655,11 +655,17 @@ sensor_event_enable_enable_all_event_messages_checkout (const char *section_name
                                                         struct config_keyvalue *kv,
                                                         void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   config_err_t rv = CONFIG_ERR_FATAL_ERROR;
   config_err_t ret;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _get_sensor_event_enable (state_data,
                                        section_name,
                                        &data)) != CONFIG_ERR_SUCCESS)
@@ -683,11 +689,17 @@ sensor_event_enable_enable_all_event_messages_commit (const char *section_name,
                                                       const struct config_keyvalue *kv,
                                                       void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   config_err_t rv = CONFIG_ERR_FATAL_ERROR;
   config_err_t ret;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _get_sensor_event_enable (state_data,
                                        section_name,
                                        &data)) != CONFIG_ERR_SUCCESS)
@@ -721,11 +733,17 @@ sensor_event_enable_enable_scanning_on_this_sensor_checkout (const char *section
                                                              struct config_keyvalue *kv,
                                                              void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   config_err_t rv = CONFIG_ERR_FATAL_ERROR;
   config_err_t ret;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _get_sensor_event_enable (state_data,
                                        section_name,
                                        &data)) != CONFIG_ERR_SUCCESS)
@@ -749,11 +767,17 @@ sensor_event_enable_enable_scanning_on_this_sensor_commit (const char *section_n
                                                            const struct config_keyvalue *kv,
                                                            void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   config_err_t rv = CONFIG_ERR_FATAL_ERROR;
   config_err_t ret;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _get_sensor_event_enable (state_data,
                                        section_name,
                                        &data)) != CONFIG_ERR_SUCCESS)
@@ -795,6 +819,8 @@ _setup_event_enable_key (ipmi_sensors_config_state_data_t *state_data,
   assert (state_data);
   assert (section);
   assert (key_name);
+  assert (checkout_func);
+  assert (commit_func);
 
   if (event_supported
       || state_data->prog_data->args->config_args.verbose_count)
@@ -937,13 +963,19 @@ threshold_event_enable_checkout (const char *section_name,
                                  struct config_keyvalue *kv,
                                  void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   uint16_t bits = 0;
   uint8_t bitposition = 0;
   config_err_t rv = CONFIG_ERR_FATAL_ERROR;
   config_err_t ret;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _threshold_event_enable_verify (state_data,
                                              section_name)) != CONFIG_ERR_SUCCESS)
     {
@@ -977,7 +1009,7 @@ threshold_event_enable_commit (const char *section_name,
                                const struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   uint16_t bits = 0;
   uint8_t bitposition = 0;
@@ -985,6 +1017,12 @@ threshold_event_enable_commit (const char *section_name,
   config_err_t ret;
   uint8_t event_message_action;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _threshold_event_enable_verify (state_data,
                                              section_name)) != CONFIG_ERR_SUCCESS)
     {
@@ -1401,7 +1439,7 @@ generic_event_enable_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   uint16_t bits = 0;
   uint8_t bitposition = 0;
@@ -1409,6 +1447,12 @@ generic_event_enable_checkout (const char *section_name,
   config_err_t ret;
   uint8_t event_reading_type_code;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _generic_event_enable_verify (state_data,
                                            section_name,
                                            &event_reading_type_code)) != CONFIG_ERR_SUCCESS)
@@ -1444,7 +1488,7 @@ generic_event_enable_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   uint16_t bits = 0;
   uint8_t bitposition = 0;
@@ -1453,6 +1497,12 @@ generic_event_enable_commit (const char *section_name,
   uint8_t event_reading_type_code;
   uint8_t event_message_action;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _generic_event_enable_verify (state_data,
                                            section_name,
                                            &event_reading_type_code)) != CONFIG_ERR_SUCCESS)
@@ -1823,7 +1873,7 @@ sensor_specific_event_enable_checkout (const char *section_name,
                                        struct config_keyvalue *kv,
                                        void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   uint16_t bits = 0;
   uint8_t bitposition = 0;
@@ -1831,6 +1881,12 @@ sensor_specific_event_enable_checkout (const char *section_name,
   config_err_t ret;
   uint8_t sensor_type;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _sensor_specific_event_enable_verify (state_data,
                                                    section_name,
                                                    &sensor_type)) != CONFIG_ERR_SUCCESS)
@@ -1866,7 +1922,7 @@ sensor_specific_event_enable_commit (const char *section_name,
                                      const struct config_keyvalue *kv,
                                      void *arg)
 {
-  ipmi_sensors_config_state_data_t *state_data = (ipmi_sensors_config_state_data_t *)arg;
+  ipmi_sensors_config_state_data_t *state_data;
   struct sensor_event_enable_data data;
   uint16_t bits = 0;
   uint8_t bitposition = 0;
@@ -1875,6 +1931,12 @@ sensor_specific_event_enable_commit (const char *section_name,
   uint8_t sensor_type;
   uint8_t event_message_action;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_sensors_config_state_data_t *)arg;
+
   if ((ret = _sensor_specific_event_enable_verify (state_data,
                                                    section_name,
                                                    &sensor_type)) != CONFIG_ERR_SUCCESS)
