@@ -1,20 +1,19 @@
 /*
-   Copyright (C) 2003-2010 FreeIPMI Core Team
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
-
+ * Copyright (C) 2003-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef _IPMI_SDR_RECORD_FORMAT_H
@@ -38,29 +37,6 @@ extern "C" {
 #define IPMI_SDR_FORMAT_BMC_MESSAGE_CHANNEL_INFO_RECORD             0x14
 #define IPMI_SDR_FORMAT_OEM_RECORD                                  0xC0
 
-#define IPMI_SDR_FORMAT_FULL_SENSOR_RECORD_NAME \
-  "Full Sensor Record"
-#define IPMI_SDR_FORMAT_COMPACT_SENSOR_RECORD_NAME \
-  "Compact Sensor Record"
-#define IPMI_SDR_FORMAT_EVENT_ONLY_RECORD_NAME \
-  "Event-Only Record"
-#define IPMI_SDR_FORMAT_ENTITY_ASSOCIATION_RECORD_NAME \
-  "Entity Association Record"
-#define IPMI_SDR_FORMAT_DEVICE_RELATIVE_ENTITY_ASSOCIATION_RECORD_NAME \
-  "Device-relative Entity Association Record"
-#define IPMI_SDR_FORMAT_GENERIC_DEVICE_LOCATOR_RECORD_NAME \
-  "Generic Device Locator Record"
-#define IPMI_SDR_FORMAT_FRU_DEVICE_LOCATOR_RECORD_NAME \
-  "FRU Device Locator Record"
-#define IPMI_SDR_FORMAT_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD_NAME \
-  "Management Controller Device Locator Record"
-#define IPMI_SDR_FORMAT_MANAGEMENT_CONTROLLER_CONFIRMATION_RECORD_NAME \
-  "Management Controller Confirmation Record"
-#define IPMI_SDR_FORMAT_BMC_MESSAGE_CHANNEL_INFO_RECORD_NAME \
-  "BMC Message Channel Info Record"
-#define IPMI_SDR_FORMAT_OEM_RECORD_NAME \
-  "OEM Record"
-
 #define IPMI_SDR_FORMAT_TYPE_VALID(__val)                                     \
   (((__val) == IPMI_SDR_FORMAT_FULL_SENSOR_RECORD                             \
     || (__val) == IPMI_SDR_FORMAT_COMPACT_SENSOR_RECORD                       \
@@ -101,18 +77,21 @@ extern "C" {
     || (__sensor_modifier_unit) == IPMI_SDR_MODIFIER_UNIT_DIVIDE \
     || (__sensor_modifier_unit) == IPMI_SDR_MODIFIER_UNIT_MULTIPLY) ? 1 : 0)
 
-#define IPMI_SDR_LINEARIZATION_LINEAR   0
-#define IPMI_SDR_LINEARIZATION_LN       1
-#define IPMI_SDR_LINEARIZATION_LOG10    2
-#define IPMI_SDR_LINEARIZATION_LOG2     3
-#define IPMI_SDR_LINEARIZATION_E        4
-#define IPMI_SDR_LINEARIZATION_EXP10    5
-#define IPMI_SDR_LINEARIZATION_EXP2     6
-#define IPMI_SDR_LINEARIZATION_INVERSE  7
-#define IPMI_SDR_LINEARIZATION_SQR      8
-#define IPMI_SDR_LINEARIZATION_CUBE     9
-#define IPMI_SDR_LINEARIZATION_SQRT    10
-#define IPMI_SDR_LINEARIZATION_CUBERT  11
+#define IPMI_SDR_LINEARIZATION_LINEAR                0
+#define IPMI_SDR_LINEARIZATION_LN                    1
+#define IPMI_SDR_LINEARIZATION_LOG10                 2
+#define IPMI_SDR_LINEARIZATION_LOG2                  3
+#define IPMI_SDR_LINEARIZATION_E                     4
+#define IPMI_SDR_LINEARIZATION_EXP10                 5
+#define IPMI_SDR_LINEARIZATION_EXP2                  6
+#define IPMI_SDR_LINEARIZATION_INVERSE               7
+#define IPMI_SDR_LINEARIZATION_SQR                   8
+#define IPMI_SDR_LINEARIZATION_CUBE                  9
+#define IPMI_SDR_LINEARIZATION_SQRT                 10
+#define IPMI_SDR_LINEARIZATION_CUBERT               11
+#define IPMI_SDR_LINEARIZATION_NON_LINEAR         0x70
+#define IPMI_SDR_LINEARIZATION_NON_LINEAR_OEM_MIN 0x71
+#define IPMI_SDR_LINEARIZATION_NON_LINEAR_OEM_MAX 0x7F
 
 #define IPMI_SDR_LINEARIZATION_LINEAR_STRING     "linear"
 #define IPMI_SDR_LINEARIZATION_LN_STRING         "ln"
@@ -134,8 +113,8 @@ extern "C" {
     && (__sensor_linearization) <= IPMI_SDR_LINEARIZATION_CUBERT) ? 1 : 0)
 
 #define IPMI_SDR_LINEARIZATION_IS_NON_LINEAR(__sensor_linearization) \
-  (((__sensor_linearization) >= 0x70                                 \
-    && (__sensor_linearization) <= 0x7F) ? 1 : 0)
+  (((__sensor_linearization) >= IPMI_SDR_LINEARIZATION_NON_LINEAR \
+    && (__sensor_linearization) <=IPMI_SDR_LINEARIZATION_NON_LINEAR_OEM_MAX) ? 1 : 0)
 
 #define IPMI_SDR_PERCENTAGE_NO  0
 #define IPMI_SDR_PERCENTAGE_YES 1
