@@ -1,20 +1,20 @@
 /*
-  Copyright (C) 2003-2010 FreeIPMI Core Team
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software Foundation,
-  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
-*/
+ * Copyright (C) 2003-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -33,7 +33,7 @@
 #include "freeipmi/spec/ipmi-channel-spec.h"
 #include "freeipmi/spec/ipmi-ipmb-lun-spec.h"
 #include "freeipmi/spec/ipmi-netfn-spec.h"
-#include "freeipmi/spec/ipmi-pef-parameter-spec.h"
+#include "freeipmi/spec/ipmi-pef-configuration-parameters-spec.h"
 
 #include "ipmi-api-defs.h"
 #include "ipmi-api-trace.h"
@@ -168,8 +168,8 @@ ipmi_cmd_set_pef_configuration_parameters (ipmi_ctx_t ctx,
       return (-1);
     }
 
-  if  ((!IPMI_PEF_PARAMETER_SELECTOR_VALID (parameter_selector)
-        && !IPMI_PEF_PARAMETER_SELECTOR_IS_OEM (parameter_selector))
+  if  ((!IPMI_PEF_CONFIGURATION_PARAMETER_SELECTOR_VALID (parameter_selector)
+        && !IPMI_PEF_CONFIGURATION_PARAMETER_SELECTOR_IS_OEM (parameter_selector))
        || !configuration_parameter_data
        || !configuration_parameter_data_len
        || !fiid_obj_valid (obj_cmd_rs))
@@ -216,6 +216,63 @@ ipmi_cmd_set_pef_configuration_parameters (ipmi_ctx_t ctx,
   return (rv);
 }
 
+int
+ipmi_cmd_set_pef_configuration_parameters_set_in_progress (ipmi_ctx_t ctx,
+                                                           uint8_t state,
+                                                           fiid_obj_t obj_cmd_rs)
+{
+  fiid_obj_t obj_cmd_rq = NULL;
+  int rv = -1;
+
+  if (!ctx || ctx->magic != IPMI_CTX_MAGIC)
+    {
+      ERR_TRACE (ipmi_ctx_errormsg (ctx), ipmi_ctx_errnum (ctx));
+      return (-1);
+    }
+
+  if  (!IPMI_PEF_CONFIGURATION_PARAMETERS_SET_IN_PROGRESS_VALID (state)
+       || !fiid_obj_valid (obj_cmd_rs))
+    {
+      API_SET_ERRNUM (ctx, IPMI_ERR_PARAMETERS);
+      return (-1);
+    }
+  
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rs,
+                                 tmpl_cmd_set_pef_configuration_parameters_rs) < 0)
+    {
+      API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rs);
+      return (-1);
+    }
+  
+  if (!(obj_cmd_rq = fiid_obj_create (tmpl_cmd_set_pef_configuration_parameters_set_in_progress_rq)))
+    {
+      API_ERRNO_TO_API_ERRNUM (ctx, errno);
+      goto cleanup;
+    }
+
+  if (fill_cmd_set_pef_configuration_parameters_set_in_progress (state,
+                                                                 obj_cmd_rq) < 0)
+    {
+      API_ERRNO_TO_API_ERRNUM (ctx, errno);
+      goto cleanup;
+    }
+
+  if (api_ipmi_cmd (ctx,
+                    IPMI_BMC_IPMB_LUN_BMC,
+                    IPMI_NET_FN_SENSOR_EVENT_RQ,
+                    obj_cmd_rq,
+                    obj_cmd_rs) < 0)
+    {
+      ERR_TRACE (ipmi_ctx_errormsg (ctx), ipmi_ctx_errnum (ctx));
+      goto cleanup;
+    }
+
+  rv = 0;
+ cleanup:
+  fiid_obj_destroy (obj_cmd_rq);
+  return (rv);
+}
+
 int
 ipmi_cmd_set_pef_configuration_parameters_pef_control (ipmi_ctx_t ctx,
                                                        uint8_t pef,
@@ -862,8 +919,8 @@ ipmi_cmd_get_pef_configuration_parameters (ipmi_ctx_t ctx,
       return (-1);
     }
 
-  if ((!IPMI_PEF_PARAMETER_SELECTOR_VALID (parameter_selector)
-       && !IPMI_PEF_PARAMETER_SELECTOR_IS_OEM (parameter_selector))
+  if ((!IPMI_PEF_CONFIGURATION_PARAMETER_SELECTOR_VALID (parameter_selector)
+       && !IPMI_PEF_CONFIGURATION_PARAMETER_SELECTOR_IS_OEM (parameter_selector))
       || !IPMI_GET_PEF_PARAMETER_VALID (get_parameter)
       || !fiid_obj_valid (obj_cmd_rs))
     {
@@ -910,6 +967,68 @@ ipmi_cmd_get_pef_configuration_parameters (ipmi_ctx_t ctx,
   return (rv);
 }
 
+int
+ipmi_cmd_get_pef_configuration_parameters_set_in_progress (ipmi_ctx_t ctx,
+                                                           uint8_t get_parameter,
+                                                           uint8_t set_selector,
+                                                           uint8_t block_selector,
+                                                           fiid_obj_t obj_cmd_rs)
+{
+  fiid_obj_t obj_cmd_rq = NULL;
+  int rv = -1;
+
+  if (!ctx || ctx->magic != IPMI_CTX_MAGIC)
+    {
+      ERR_TRACE (ipmi_ctx_errormsg (ctx), ipmi_ctx_errnum (ctx));
+      return (-1);
+    }
+
+  if (!IPMI_GET_PEF_PARAMETER_VALID (get_parameter)
+      || !fiid_obj_valid (obj_cmd_rs))
+    {
+      API_SET_ERRNUM (ctx, IPMI_ERR_PARAMETERS);
+      return (-1);
+    }
+
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rs,
+                                 tmpl_cmd_get_pef_configuration_parameters_set_in_progress_rs) < 0)
+    {
+      API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rs);
+      return (-1);
+    }
+
+  if (!(obj_cmd_rq = fiid_obj_create (tmpl_cmd_get_pef_configuration_parameters_rq)))
+    {
+      API_ERRNO_TO_API_ERRNUM (ctx, errno);
+      goto cleanup;
+    }
+
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_SET_IN_PROGRESS,
+                                                 get_parameter,
+                                                 set_selector,
+                                                 block_selector,
+                                                 obj_cmd_rq) < 0)
+    {
+      API_ERRNO_TO_API_ERRNUM (ctx, errno);
+      goto cleanup;
+    }
+
+  if (api_ipmi_cmd (ctx,
+                    IPMI_BMC_IPMB_LUN_BMC,
+                    IPMI_NET_FN_SENSOR_EVENT_RQ,
+                    obj_cmd_rq,
+                    obj_cmd_rs) < 0)
+    {
+      ERR_TRACE (ipmi_ctx_errormsg (ctx), ipmi_ctx_errnum (ctx));
+      goto cleanup;
+    }
+
+  rv = 0;
+ cleanup:
+  fiid_obj_destroy (obj_cmd_rq);
+  return (rv);
+}
+
 int
 ipmi_cmd_get_pef_configuration_parameters_pef_control (ipmi_ctx_t ctx,
                                                        uint8_t get_parameter,
@@ -946,7 +1065,7 @@ ipmi_cmd_get_pef_configuration_parameters_pef_control (ipmi_ctx_t ctx,
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_PEF_CONTROL,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_PEF_CONTROL,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1008,7 +1127,7 @@ ipmi_cmd_get_pef_configuration_parameters_pef_action_global_control (ipmi_ctx_t
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_PEF_ACTION_GLOBAL_CONTROL,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_PEF_ACTION_GLOBAL_CONTROL,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1070,7 +1189,7 @@ ipmi_cmd_get_pef_configuration_parameters_pef_startup_delay (ipmi_ctx_t ctx,
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_PEF_STARTUP_DELAY,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_PEF_STARTUP_DELAY,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1132,7 +1251,7 @@ ipmi_cmd_get_pef_configuration_parameters_pef_alert_startup_delay (ipmi_ctx_t ct
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_PEF_ALERT_STARTUP_DELAY,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_PEF_ALERT_STARTUP_DELAY,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1194,7 +1313,7 @@ ipmi_cmd_get_pef_configuration_parameters_number_of_event_filters (ipmi_ctx_t ct
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_NUMBER_OF_EVENT_FILTERS,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_NUMBER_OF_EVENT_FILTERS,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1256,7 +1375,7 @@ ipmi_cmd_get_pef_configuration_parameters_event_filter_table (ipmi_ctx_t ctx,
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_EVENT_FILTER_TABLE,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_EVENT_FILTER_TABLE,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1318,7 +1437,7 @@ ipmi_cmd_get_pef_configuration_parameters_event_filter_table_data1_ (ipmi_ctx_t
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_EVENT_FILTER_TABLE_DATA_1,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_EVENT_FILTER_TABLE_DATA_1,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1380,7 +1499,7 @@ ipmi_cmd_get_pef_configuration_parameters_number_of_alert_policy_entries (ipmi_c
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_NUMBER_OF_ALERT_POLICY_ENTRIES,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_NUMBER_OF_ALERT_POLICY_ENTRIES,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1442,7 +1561,7 @@ ipmi_cmd_get_pef_configuration_parameters_number_of_alert_strings (ipmi_ctx_t ct
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_NUMBER_OF_ALERT_STRINGS,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_NUMBER_OF_ALERT_STRINGS,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1504,7 +1623,7 @@ ipmi_cmd_get_pef_configuration_parameters_alert_string_keys (ipmi_ctx_t ctx,
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_ALERT_STRING_KEYS,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_ALERT_STRING_KEYS,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1566,7 +1685,7 @@ ipmi_cmd_get_pef_configuration_parameters_alert_string (ipmi_ctx_t ctx,
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_ALERT_STRINGS,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_ALERT_STRINGS,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
@@ -1628,7 +1747,7 @@ ipmi_cmd_get_pef_configuration_parameters_alert_policy_table (ipmi_ctx_t ctx,
       goto cleanup;
     }
 
-  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_PARAMETER_ALERT_POLICY_TABLE,
+  if (fill_cmd_get_pef_configuration_parameters (IPMI_PEF_CONFIGURATION_PARAMETER_ALERT_POLICY_TABLE,
                                                  get_parameter,
                                                  set_selector,
                                                  block_selector,
